module.exports = {
  title: 'rtl_433',
  description: 'generic data receiver for ISM/SRD bands.',
  base: "/rtl_433/",
  markdown: {
    linkify: true
  },
  themeConfig: {
    repo: 'merbanan/rtl_433',
    displayAllHeaders: true,
    sidebar: [
      ['/', 'Overview'],
      'BUILDING',
      'VS15',
      'CHANGELOG',
      'CONTRIBUTING',
      'PRIMER',
      'IQ_FORMATS',
      'ANALYZE',
      'OPERATION',
      'DATA_FORMAT',
      'HARDWARE',
      'INTEGRATION',
      'LINKS',
      'TESTS',
    ]
  }
};
